@@ -1,12 +1,12 @@
 #' Plotting method for \code{LCx} objects
 #'
 #' This is the generic \code{plot} S3 method for the
-#' \\code{LCx} class. It plots the survival rate as a function of concentration.
+#' \\code{LCx} class. It plots the survival probability as a function of concentration.
 #'
 #'
 #' @param x An object of class \code{LCx}.
 #' @param xlab A label for the \eqn{X}-axis, by default \code{Concentration}.
-#' @param ylab A label for the \eqn{Y}-axis, by default \code{Survival rate median and 95 CI}.
+#' @param ylab A label for the \eqn{Y}-axis, by default \code{Survival probability median and 95 CI}.
 #' @param main A main title for the plot.
 #' @param subtitle A subtitle for the plot
 #' @param \dots Further arguments to be passed to generic methods.
@@ -38,7 +38,7 @@
 #'
 plot.LCx <- function(x,
                      xlab = "Concentration",
-                     ylab = "Survival rate \n median and 95 CI",
+                     ylab = "Survival probability \n median and 95 CI",
                      main = NULL,
                      subtitle = NULL,
                      ...){
